pub struct SplitMix64 { /* private fields */ }Expand description
A splitmix64 random number generator.
The splitmix algorithm is not suitable for cryptographic purposes, but is very fast and has a 64 bit state.
The algorithm used here is translated from the splitmix64.c
reference source code by
Sebastiano Vigna. For next_u32, a more efficient mixing function taken
from dsiutils is used.
Implementations
Sourceimpl SplitMix64
impl SplitMix64
Sourcepub fn state(&self) -> [u8; 8]
pub fn state(&self) -> [u8; 8]
Return the internal state of the generator as little-endian bytes
that can be passed to SeedableRng::from_seed to reconstruct an
identical generator.