pub struct Xoroshiro128Plus { /* private fields */ }Expand description
A xoroshiro128+ random number generator.
The xoroshiro128+ algorithm is not suitable for cryptographic purposes, but is very fast and has good statistical properties, besides a low linear complexity in the lowest bits.
The algorithm used here is translated from the xoroshiro128plus.c
reference source code by
David Blackman and Sebastiano Vigna.
Implementations
Sourceimpl Xoroshiro128Plus
impl Xoroshiro128Plus
Sourcepub fn jump(&mut self)
pub fn jump(&mut self)
Jump forward, equivalently to 2^64 calls to next_u64().
This can be used to generate 2^64 non-overlapping subsequences for parallel computations.
use rand_xoshiro::rand_core::SeedableRng;
use rand_xoshiro::Xoroshiro128Plus;
let rng1 = Xoroshiro128Plus::seed_from_u64(0);
let mut rng2 = rng1.clone();
rng2.jump();
let mut rng3 = rng2.clone();
rng3.jump();Sourceimpl Xoroshiro128Plus
impl Xoroshiro128Plus
Sourcepub fn state(&self) -> [u8; 16]
pub fn state(&self) -> [u8; 16]
Return the internal state of the generator as little-endian
bytes that can be passed to SeedableRng::from_seed to
reconstruct an identical generator.
The all-zero state is unreachable from any non-zero seed, so
the round-trip is exact for any generator obtained via the
usual constructors. (An all-zero input to from_seed is
remapped to seed_from_u64(0).)