Xoshiro128PlusPlus

Struct Xoshiro128PlusPlus 

pub struct Xoshiro128PlusPlus { /* private fields */ }
A xoshiro128++ random number generator.

The xoshiro128++ algorithm is not suitable for cryptographic purposes, but is very fast and has excellent statistical properties.

The algorithm used here is translated from the xoshiro128plusplus.c reference source code by David Blackman and Sebastiano Vigna.

Implementations

Source

impl Xoshiro128PlusPlus

pub fn jump(&mut self)

Jump forward, equivalently to 2^64 calls to next_u32().

This can be used to generate 2^64 non-overlapping subsequences for parallel computations.

use rand_xoshiro::rand_core::SeedableRng;
use rand_xoshiro::Xoroshiro128PlusPlus;

let rng1 = Xoroshiro128PlusPlus::seed_from_u64(0);
let mut rng2 = rng1.clone();
rng2.jump();
let mut rng3 = rng2.clone();
rng3.jump();
pub fn long_jump(&mut self)

Jump forward, equivalently to 2^96 calls to next_u32().

This can be used to generate 2^32 starting points, from each of which jump() will generate 2^32 non-overlapping subsequences for parallel distributed computations.

Source

impl Xoshiro128PlusPlus

pub fn state(&self) -> [u8; 16]

Return the internal state of the generator as little-endian bytes that can be passed to SeedableRng::from_seed to reconstruct an identical generator.

The all-zero state is unreachable from any non-zero seed, so the round-trip is exact for any generator obtained via the usual constructors. (An all-zero input to from_seed is remapped to seed_from_u64(0).)