pub struct Xoshiro256PlusPlus { /* private fields */ }Expand description
A xoshiro256++ random number generator.
The xoshiro256++ algorithm is not suitable for cryptographic purposes, but is very fast and has excellent statistical properties.
The algorithm used here is translated from the xoshiro256plusplus.c
reference source code by
David Blackman and Sebastiano Vigna.
Implementations
Sourceimpl Xoshiro256PlusPlus
impl Xoshiro256PlusPlus
Sourcepub fn jump(&mut self)
pub fn jump(&mut self)
Jump forward, equivalently to 2^128 calls to next_u64().
This can be used to generate 2^128 non-overlapping subsequences for parallel computations.
use rand_xoshiro::rand_core::SeedableRng;
use rand_xoshiro::Xoshiro256PlusPlus;
let rng1 = Xoshiro256PlusPlus::seed_from_u64(0);
let mut rng2 = rng1.clone();
rng2.jump();
let mut rng3 = rng2.clone();
rng3.jump();Sourceimpl Xoshiro256PlusPlus
impl Xoshiro256PlusPlus
Sourcepub fn state(&self) -> [u8; 32]
pub fn state(&self) -> [u8; 32]
Return the internal state of the generator as little-endian
bytes that can be passed to SeedableRng::from_seed to
reconstruct an identical generator.
The all-zero state is unreachable from any non-zero seed, so
the round-trip is exact for any generator obtained via the
usual constructors. (An all-zero input to from_seed is
remapped to seed_from_u64(0).)